@@ -71,6 +71,7 @@ define ([
             prop: null,
             maxlen: 20
         },
+
         emptyLineEntry: {
             name: 'emptyLine',
             aclProfileRead: 'passerby',
@@ -86,6 +87,11 @@ define ([
             $('#result').html('&nbsp;');
         },
 
+        displayResult: function (buf) {
+            $('#result').css('text-align', 'center');
+            $('#result').html(buf);
+        },
+
         ajaxMessage: function () {
             $('#result').css('text-align', 'center');
             $('#result').html('* * * AJAX call * * *');
@@ -287,7 +293,15 @@ define ([
         isObjEmpty: function (obj) {
             if (Object.getOwnPropertyNames(obj).length > 0) return false;
             return true;
-        }
+        },
+
+        focusedItem: function () {
+            return {
+                "id": $(document.activeElement).attr('id'),
+                "name": $(document.activeElement).attr('name'),
+            };
+        },
+
     };
 });
 
