@@ -35,8 +35,10 @@
 "use strict";
 
 define ([
+    'QUnit',
     'prototypes'
 ], function (
+    QUnit,
     prototypes 
 ) {
 
@@ -47,7 +49,7 @@ define ([
         var t = Object.create(prototypes.target),
             u = Object.create(prototypes.user);
 
-        test(prefix + 'prototypes prototyping?', function (assert) {
+        QUnit.test(prefix + 'prototypes prototyping?', function (assert) {
 
             // target
             assert.strictEqual(typeof t, 'object', 't is an object');
@@ -64,10 +66,8 @@ define ([
             assert.strictEqual(typeof u, 'object', 'u is an object');
             assert.strictEqual(typeof u.nick, 'string', 'user.nick OK');
             assert.strictEqual(u.nick, '', 'user.nick OK');
-            assert.strictEqual(typeof u.passhash, 'string', 'user.passhash OK');
-            assert.strictEqual(u.passhash, '', 'user.nick OK');
-            assert.strictEqual(typeof u.salt, 'string', 'user.salt OK');
-            assert.strictEqual(u.salt, '', 'user.nick OK');
+            assert.notOk(u.hasOwnProperty('passhash'), 'user prototype has no passhash property');
+            assert.notOk(u.hasOwnProperty('salt'), 'user prototype has no salt property');
 
         });
 
